@@ -56,7 +56,7 @@ get_type_from_field (JsonObject *json_object, const gchar *field)
 
 	node = json_object_get_member (json_object, field);
 	if (node == NULL)
-		G_TYPE_INVALID;
+		return G_TYPE_INVALID;
 
 	type = json_node_get_value_type (node);
 	switch (type) {
